@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 13367 2021-12-24 04:53:31Z Mint $
+# $Id: __init__.py 13374 2022-01-15 07:17:59Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Mint $ (last)
-# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
-# $Revision: 13367 $
+# $Author: Lavender $ (last)
+# $Date: 2022-01-15 15:17:59 +0800 (週六, 15 一月 2022) $
+# $Revision: 13374 $
 
 from __future__ import print_function
 
@@ -656,7 +656,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'DIRS': [os.path.join(settingsDict.get('BASE_DIR', projectPath),
                               'templates'),],
         # 需要這個才能找到 site-packages 裡面的 templates
-        #'APP_DIRS': True,
+        'APP_DIRS': True,
         'OPTIONS': {
             'context_processors': [
                 'django.template.context_processors.debug',
