@@ -26,13 +26,10 @@ from django.conf import settings
 from django.urls import reverse
 from django.http import JsonResponse, Http404
 from django.views.decorators.csrf import csrf_exempt
-from django.dispatch import Signal
 
-from Iuno.cloud.sms import SMS, verify
+from Iuno.cloud.sms import SMS, verify, smsAfterVerify
 from Iuppiter.Encryption import Encryptor
 
-smsAfterVerify = Signal()
-
 @csrf_exempt  
 def sendSMSAuthentication(request):
     if request.POST:
