@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 13328 2021-09-13 07:12:34Z Becca $
+# $Id: forms.py 13367 2021-12-24 04:53:31Z Mint $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Becca $ (last)
-# $Date: 2021-09-13 15:12:34 +0800 (週一, 13 九月 2021) $
-# $Revision: 13328 $
+# $Author: Mint $ (last)
+# $Date: 2021-12-24 12:53:31 +0800 (週五, 24 十二月 2021) $
+# $Revision: 13367 $
 
 import os
 import re
@@ -561,6 +561,8 @@ if VERSION >= (2, 0, 0):
                     'optionGroup': None,
                 }
             )
+            if not hasattr(option,'is_required'):
+                option.is_required = False
             kwargs = {
                 'required': option.is_required,
                 'label': option.name,
