@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 13368 2022-01-01 08:52:58Z Lavender $
+# $Id: admin.py 13370 2022-01-08 13:23:26Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2022-01-01 16:52:58 +0800 (週六, 01 一月 2022) $
-# $Revision: 13368 $
+# $Date: 2022-01-08 21:23:26 +0800 (週六, 08 一月 2022) $
+# $Revision: 13370 $
 
 import os
 import datetime
@@ -58,7 +58,7 @@ logger = createLogger(__name__)
 class FolderForm(forms.ModelForm):
     class Meta(object):
         model = Static
-        exclude = ('parent', 'type', 'name')
+        exclude = ('parent', 'type', 'name', 'rootPath')
 
 class FileForm(forms.ModelForm):
     file = forms.FileField(
@@ -66,7 +66,7 @@ class FileForm(forms.ModelForm):
 
     class Meta(object):
         model = Static
-        exclude = ('parent', 'type', 'name')
+        exclude = ('parent', 'type', 'name', 'rootPath')
 
 class TextForm(forms.ModelForm):
     content = forms.CharField(
@@ -74,14 +74,14 @@ class TextForm(forms.ModelForm):
 
     class Meta(object):
         model = Static
-        exclude = ('parent', 'type', 'name')
+        exclude = ('parent', 'type', 'name', 'rootPath')
 
 class ImageForm(forms.ModelForm):
     image = forms.ImageField(label=_('Image'), required=False)
 
     class Meta(object):
         model = Static
-        exclude = ('parent', 'type', 'name')
+        exclude = ('parent', 'type', 'name', 'rootPath')
 
 def createVersion(model, node, conflict=False):
     fileName = node.name.split('.')[0]
@@ -320,7 +320,7 @@ class BaseFileAdmin(admin.ModelAdmin):
         if subFileName in TEXT_SUB_FILE_NAME:
             form = TextForm
             with open(fullPath, 'rb') as f:
-                data = f.read().decode('utf-8')
+                data = f.read().decode("utf-8")
             form.base_fields['content'].initial = data
         elif subFileName in IMAGE_SUB_FILE_NAME:
             form = ImageForm
